@@ -3,7 +3,7 @@ package CPAN::Plugin::Sysdeps::Mapping;
 use strict;
 use warnings;
 
-our $VERSION = '0.47';
+our $VERSION = '0.48';
 
 # shortcuts
 #  os and distros
@@ -1479,7 +1479,10 @@ sub mapping {
       #[os_freebsd,
       # [package => 'opencv']], # package for decodeqr missing
       [like_debian,
-       [package => ['libopencv-dev', 'libdecodeqr-dev']]]],
+       [before_debian_stretch,
+	[package => ['libopencv-dev', 'libdecodeqr-dev']]],
+       [package => []], # not available anymore in stretch, but currently available in sid for at least arm64
+      ]],
 
      [cpanmod => ['Image::ObjectDetect', 'Image::Resize::OpenCV'],
       [os_freebsd,
@@ -1618,6 +1621,8 @@ sub mapping {
        [linuxdistrocodename => [qw(stretch xenial)],
 	[package => 'openjdk-8-jdk']],
       ],
+      [like_fedora,
+       [package => 'java-1.8.0-openjdk-devel | java-1.7.0-openjdk-devel | java-1.6.0-openjdk-devel']],
      ],
 
      [cpanmod => 'Inline::Lua',
